==> scorchful-0.15.5%2B1.21.4-sources.jar: com/github/thedeathlycow/scorchful/temperature/heatvision/VisionGenerator.java <==
package com.github.thedeathlycow.scorchful.temperature.heatvision;

import com.github.thedeathlycow.scorchful.registry.SRegistries;
import it.unimi.dsi.fastutil.objects.Object2ObjectOpenHashMap;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import java.util.Map;
import java.util.Optional;
import net.minecraft.class_1959;
import net.minecraft.class_2338;
import net.minecraft.class_3218;
import net.minecraft.class_5321;
import net.minecraft.class_6011;
import net.minecraft.class_6880;

public class VisionGenerator {

    private final Map<class_5321<class_1959>, List<HeatVision>> cache = new Object2ObjectOpenHashMap<>();

    @Nullable
    public HeatVision chooseVision(class_3218 serverWorld, class_2338 pos) {
        List<HeatVision> controllers = this.getPossibleVisions(serverWorld.method_23753(pos));
        if (controllers.isEmpty()) {
            return null;
        }

        return class_6011.method_34986(serverWorld.method_8409(), controllers).orElseThrow(IllegalStateException::new);
    }

    private List<HeatVision> getPossibleVisions(class_6880<class_1959> biome) {
        Optional<class_5321<class_1959>> key = biome.method_40230();
        if (key.isEmpty()) {
            return List.of();
        }
        return this.cache.computeIfAbsent(key.get(), k -> this.computeVisionsForBiome(biome));
    }


    private List<HeatVision> computeVisionsForBiome(class_6880<class_1959> biome) {
        return SRegistries.HEAT_VISION.method_10220()
                .filter(vision -> vision.canApplyToBiome(biome))
                .toList();
    }

}

==> scorchful-0.16.0%2B1.21.9-sources.jar: com/github/thedeathlycow/scorchful/temperature/heatvision/VisionGenerator.java <==
package com.github.thedeathlycow.scorchful.temperature.heatvision;

import com.github.thedeathlycow.scorchful.registry.SRegistries;
import it.unimi.dsi.fastutil.objects.Object2ObjectOpenHashMap;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import java.util.Map;
import java.util.Optional;
import net.minecraft.class_1959;
import net.minecraft.class_2338;
import net.minecraft.class_3218;
import net.minecraft.class_5321;
import net.minecraft.class_6011;
import net.minecraft.class_6880;

public class VisionGenerator {

    private final Map<class_5321<class_1959>, List<HeatVision>> cache = new Object2ObjectOpenHashMap<>();

    @Nullable
    public HeatVision chooseVision(class_3218 serverWorld, class_2338 pos) {
        List<HeatVision> controllers = this.getPossibleVisions(serverWorld.method_23753(pos));
        if (controllers.isEmpty()) {
            return null;
        }

        return class_6011.method_34986(serverWorld.method_8409(), controllers, HeatVision::getWeight)
                .orElseThrow(IllegalStateException::new);
    }

    private List<HeatVision> getPossibleVisions(class_6880<class_1959> biome) {
        Optional<class_5321<class_1959>> key = biome.method_40230();
        if (key.isEmpty()) {
            return List.of();
        }
        return this.cache.computeIfAbsent(key.get(), k -> this.computeVisionsForBiome(biome));
    }


    private List<HeatVision> computeVisionsForBiome(class_6880<class_1959> biome) {
        return SRegistries.HEAT_VISION.method_10220()
                .filter(vision -> vision.canApplyToBiome(biome))
                .toList();
    }

}
